@@ -1,13 +1,14 @@
 import React, {PropTypes, Component} from 'react';
 import FormTextInput from './form-text-input';
 
-//TODO Check if min and max are not defined
-
 export default function FormNumberInput({onChange, ...rest}) {
   let onChangeCustom = event => {
     let value = event.target.value;
 
-    if( value <= rest.min || value >= rest.max )
+    rest.min = rest.min ? parseFloat(rest.min) : -Infinity;
+    rest.max = rest.max ? parseFloat(rest.max) : Infinity;
+
+    if( parseFloat( value ) <= ( parseFloat( rest.min ) || -Infinity ) || parseFloat( value ) >= ( parseFloat( rest.max ) || Infinity ) )
     {
       event.target.value = rest.min;
       onChange(event);
@@ -23,16 +24,16 @@ export default function FormNumberInput({onChange, ...rest}) {
       {
         if( value === '-' )
         {
-          if( rest.min <= 0 )
+          if( rest.min == 0 )
           {
-            event.target.value = 0;
+            event.target.value = '0';
             event.target.select();
-            onChange(event);
           }
+          onChange(event);
         }
         else if( value === '0' || value === '' )
         {
-          event.target.value = rest.min;
+          event.target.value = rest.min > 0 ? rest.min : '0';
           onChange(event);
           event.target.select();
         }
